@@ -25,11 +25,12 @@
 #' # estimate model with 3 competitors only
 #' em_n3 <- em_2var(tb, "Sm1", "Sm2", "y", N_max = 3)
 #'
+#'
+#' \dontrun{
 #' # estimate model with different initial conditions
 #' em_difc <- em_2var(tb, "Sm1", "Sm2", "y", alpha0 = rep(0.2, 5), gamma0 = rep(1.1, 5))
 #'
-#'
-#' \dontrun{
+#' # estimate model with example data
 #' tb <- load_example_data()
 #' em <- em_2var(tb, "Populacao", "RendaPerCapita", "n_agencias")
 #' }
@@ -42,7 +43,19 @@
 #' @export
 
 em_2var <- function(data, Sm1, Sm2, y, N_max = 5,
-                    alpha0 = rep(0.1, N_max), gamma0 = rep(1, N_max)) {
+                    alpha0 = rep(0.1, N_max),
+                    gamma0 = rep(1, N_max)) {
+
+
+    # check arguments ---------------------------------------------------------
+    if (!is.character(Sm1) | !is.character(Sm2) | !is.character(y)) {
+        stop("Arguments 'Sm1', 'Sm2' and 'y' must be strings.")
+    }
+
+    if (N_max < 1 | N_max%%1 != 0) {
+        stop("'N_max' must be an integer larger than 0")
+    }
+
 
     ### to tibble
     data <- dplyr::as_tibble(data)
