@@ -24,11 +24,12 @@
 #' # estimate model with 3 competitors only
 #' em_n3 <- em_basic(tb, "Sm", "y", N_max = 3)
 #'
+#'
+#' \dontrun{
 #' # estimate model with different initial conditions
 #' em_difc <- em_basic(tb, "Sm", "y", alpha0 = rep(0.2, 5), gamma0 = rep(1.1, 5))
 #'
-#'
-#' \dontrun{
+#' # estimate model with example data
 #' tb <- load_example_data()
 #' em <- em_basic(tb, "Populacao", "n_agencias")
 #' }
@@ -40,7 +41,19 @@
 #'
 #' @export
 
-em_basic <- function(data, Sm, y, N_max = 5, alpha0 = rep(0.1, N_max), gamma0 = rep(1, N_max)) {
+em_basic <- function(data, Sm, y, N_max = 5,
+                     alpha0 = rep(0.1, N_max),
+                     gamma0 = rep(1, N_max)) {
+
+    # check arguments ---------------------------------------------------------
+    if (!is.character(Sm) | !is.character(y)) {
+        stop("Arguments 'Sm1', 'Sm2' and 'y' must be strings.")
+    }
+
+    if (N_max < 1 | N_max%%1 != 0) {
+        stop("'N_max' must be an integer larger than 0")
+    }
+
 
     ### to tibble
     data <- dplyr::as_tibble(data)
